<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Hora de Greenwich (Abidjan)',
        'Africa/Accra' => 'Hora de Greenwich (Acra)',
        'Africa/Addis_Ababa' => 'Hora da África Oriental (Adis-Abeba)',
        'Africa/Algiers' => 'Hora da Europa Central (Argel)',
        'Africa/Asmera' => 'Hora da África Oriental (Asmara)',
        'Africa/Bamako' => 'Hora de Greenwich (Bamaco)',
        'Africa/Bangui' => 'Hora da África Ocidental (Bangui)',
        'Africa/Banjul' => 'Hora de Greenwich (Banjul)',
        'Africa/Bissau' => 'Hora de Greenwich (Bissau)',
        'Africa/Blantyre' => 'Hora da África Central (Blantyre)',
        'Africa/Brazzaville' => 'Hora da África Ocidental (Brazzaville)',
        'Africa/Bujumbura' => 'Hora da África Central (Bujumbura)',
        'Africa/Cairo' => 'Hora da Europa Oriental (Cairo)',
        'Africa/Casablanca' => 'Hora da Europa Ocidental (Casablanca)',
        'Africa/Ceuta' => 'Hora da Europa Central (Ceuta)',
        'Africa/Conakry' => 'Hora de Greenwich (Conacri)',
        'Africa/Dakar' => 'Hora de Greenwich (Dacar)',
        'Africa/Dar_es_Salaam' => 'Hora da África Oriental (Dar es Salaam)',
        'Africa/Djibouti' => 'Hora da África Oriental (Jibuti)',
        'Africa/Douala' => 'Hora da África Ocidental (Douala)',
        'Africa/El_Aaiun' => 'Hora da Europa Ocidental (El Aaiún)',
        'Africa/Freetown' => 'Hora de Greenwich (Freetown)',
        'Africa/Gaborone' => 'Hora da África Central (Gaborone)',
        'Africa/Harare' => 'Hora da África Central (Harare)',
        'Africa/Johannesburg' => 'Hora da África do Sul (Joanesburgo)',
        'Africa/Juba' => 'Hora da África Central (Juba)',
        'Africa/Kampala' => 'Hora da África Oriental (Campala)',
        'Africa/Khartoum' => 'Hora da África Central (Cartum)',
        'Africa/Kigali' => 'Hora da África Central (Kigali)',
        'Africa/Kinshasa' => 'Hora da África Ocidental (Kinshasa)',
        'Africa/Lagos' => 'Hora da África Ocidental (Lagos)',
        'Africa/Libreville' => 'Hora da África Ocidental (Libreville)',
        'Africa/Lome' => 'Hora de Greenwich (Lomé)',
        'Africa/Luanda' => 'Hora da África Ocidental (Luanda)',
        'Africa/Lubumbashi' => 'Hora da África Central (Lubumbashi)',
        'Africa/Lusaka' => 'Hora da África Central (Lusaca)',
        'Africa/Malabo' => 'Hora da África Ocidental (Malabo)',
        'Africa/Maputo' => 'Hora da África Central (Maputo)',
        'Africa/Maseru' => 'Hora da África do Sul (Maseru)',
        'Africa/Mbabane' => 'Hora da África do Sul (Mbabane)',
        'Africa/Mogadishu' => 'Hora da África Oriental (Mogadíscio)',
        'Africa/Monrovia' => 'Hora de Greenwich (Monróvia)',
        'Africa/Nairobi' => 'Hora da África Oriental (Nairobi)',
        'Africa/Ndjamena' => 'Hora da África Ocidental (Ndjamena)',
        'Africa/Niamey' => 'Hora da África Ocidental (Niamei)',
        'Africa/Nouakchott' => 'Hora de Greenwich (Nouakchott)',
        'Africa/Ouagadougou' => 'Hora de Greenwich (Ouagadougou)',
        'Africa/Porto-Novo' => 'Hora da África Ocidental (Porto-Novo)',
        'Africa/Sao_Tome' => 'Hora de Greenwich (São Tomé)',
        'Africa/Tripoli' => 'Hora da Europa Oriental (Tripoli)',
        'Africa/Tunis' => 'Hora da Europa Central (Tunes)',
        'Africa/Windhoek' => 'Hora da África Central (Windhoek)',
        'America/Adak' => 'Hora do Havai e Aleutas (Adak)',
        'America/Anchorage' => 'Hora do Alasca (Anchorage)',
        'America/Anguilla' => 'Hora do Atlântico (Anguila)',
        'America/Antigua' => 'Hora do Atlântico (Antígua)',
        'America/Araguaina' => 'Hora de Brasília (Araguaina)',
        'America/Argentina/La_Rioja' => 'Hora da Argentina (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'Hora da Argentina (Rio Gallegos)',
        'America/Argentina/Salta' => 'Hora da Argentina (Salta)',
        'America/Argentina/San_Juan' => 'Hora da Argentina (San Juan)',
        'America/Argentina/San_Luis' => 'Hora da Argentina (San Luis)',
        'America/Argentina/Tucuman' => 'Hora da Argentina (Tucumán)',
        'America/Argentina/Ushuaia' => 'Hora da Argentina (Ushuaia)',
        'America/Aruba' => 'Hora do Atlântico (Aruba)',
        'America/Asuncion' => 'Hora do Paraguai (Assunção)',
        'America/Bahia' => 'Hora de Brasília (Baía)',
        'America/Bahia_Banderas' => 'Hora central norte-americana (Bahia Banderas)',
        'America/Barbados' => 'Hora do Atlântico (Barbados)',
        'America/Belem' => 'Hora de Brasília (Belém)',
        'America/Belize' => 'Hora central norte-americana (Belize)',
        'America/Blanc-Sablon' => 'Hora do Atlântico (Blanc-Sablon)',
        'America/Boa_Vista' => 'Hora do Amazonas (Boa Vista)',
        'America/Bogota' => 'Hora da Colômbia (Bogotá)',
        'America/Boise' => 'Hora de montanha norte-americana (Boise)',
        'America/Buenos_Aires' => 'Hora da Argentina (Buenos Aires)',
        'America/Cambridge_Bay' => 'Hora de montanha norte-americana (Cambridge Bay)',
        'America/Campo_Grande' => 'Hora do Amazonas (Campo Grande)',
        'America/Cancun' => 'Hora oriental norte-americana (Cancun)',
        'America/Caracas' => 'Hora da Venezuela (Caracas)',
        'America/Catamarca' => 'Hora da Argentina (Catamarca)',
        'America/Cayenne' => 'Hora da Guiana Francesa (Caiena)',
        'America/Cayman' => 'Hora oriental norte-americana (Caimão)',
        'America/Chicago' => 'Hora central norte-americana (Chicago)',
        'America/Chihuahua' => 'Hora central norte-americana (Chihuahua)',
        'America/Ciudad_Juarez' => 'Hora de montanha norte-americana (Ciudad Juárez)',
        'America/Coral_Harbour' => 'Hora oriental norte-americana (Atikokan)',
        'America/Cordoba' => 'Hora da Argentina (Córdoba)',
        'America/Costa_Rica' => 'Hora central norte-americana (Costa Rica)',
        'America/Creston' => 'Hora de montanha norte-americana (Creston)',
        'America/Cuiaba' => 'Hora do Amazonas (Cuiabá)',
        'America/Curacao' => 'Hora do Atlântico (Curaçau)',
        'America/Danmarkshavn' => 'Hora de Greenwich (Danmarkshavn)',
        'America/Dawson' => 'Hora do Yukon (Dawson)',
        'America/Dawson_Creek' => 'Hora de montanha norte-americana (Dawson Creek)',
        'America/Denver' => 'Hora de montanha norte-americana (Denver)',
        'America/Detroit' => 'Hora oriental norte-americana (Detroit)',
        'America/Dominica' => 'Hora do Atlântico (Domínica)',
        'America/Edmonton' => 'Hora de montanha norte-americana (Edmonton)',
        'America/Eirunepe' => 'Hora do Acre (Eirunepé)',
        'America/El_Salvador' => 'Hora central norte-americana (Salvador)',
        'America/Fort_Nelson' => 'Hora de montanha norte-americana (Fort Nelson)',
        'America/Fortaleza' => 'Hora de Brasília (Fortaleza)',
        'America/Glace_Bay' => 'Hora do Atlântico (Glace Bay)',
        'America/Godthab' => 'Hora da Gronelândia Ocidental (Nuuk)',
        'America/Goose_Bay' => 'Hora do Atlântico (Goose Bay)',
        'America/Grand_Turk' => 'Hora oriental norte-americana (Grand Turk)',
        'America/Grenada' => 'Hora do Atlântico (Granada)',
        'America/Guadeloupe' => 'Hora do Atlântico (Guadalupe)',
        'America/Guatemala' => 'Hora central norte-americana (Guatemala)',
        'America/Guayaquil' => 'Hora do Equador (Guaiaquil)',
        'America/Guyana' => 'Hora da Guiana',
        'America/Halifax' => 'Hora do Atlântico (Halifax)',
        'America/Havana' => 'Hora de Cuba (Havana)',
        'America/Hermosillo' => 'Hora do Pacífico Mexicano (Hermosillo)',
        'America/Indiana/Knox' => 'Hora central norte-americana (Knox, Indiana)',
        'America/Indiana/Marengo' => 'Hora oriental norte-americana (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'Hora oriental norte-americana (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'Hora central norte-americana (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'Hora oriental norte-americana (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'Hora oriental norte-americana (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'Hora oriental norte-americana (Winamac, Indiana)',
        'America/Indianapolis' => 'Hora oriental norte-americana (Indianápolis)',
        'America/Inuvik' => 'Hora de montanha norte-americana (Inuvik)',
        'America/Iqaluit' => 'Hora oriental norte-americana (Iqaluit)',
        'America/Jamaica' => 'Hora oriental norte-americana (Jamaica)',
        'America/Jujuy' => 'Hora da Argentina (Jujuy)',
        'America/Juneau' => 'Hora do Alasca (Juneau)',
        'America/Kentucky/Monticello' => 'Hora oriental norte-americana (Monticello, Kentucky)',
        'America/Kralendijk' => 'Hora do Atlântico (Kralendijk)',
        'America/La_Paz' => 'Hora da Bolívia (La Paz)',
        'America/Lima' => 'Hora do Peru (Lima)',
        'America/Los_Angeles' => 'Hora do Pacífico norte-americana (Los Angeles)',
        'America/Louisville' => 'Hora oriental norte-americana (Louisville)',
        'America/Lower_Princes' => 'Hora do Atlântico (Lower Prince’s Quarter)',
        'America/Maceio' => 'Hora de Brasília (Maceió)',
        'America/Managua' => 'Hora central norte-americana (Manágua)',
        'America/Manaus' => 'Hora do Amazonas (Manaus)',
        'America/Marigot' => 'Hora do Atlântico (Marigot)',
        'America/Martinique' => 'Hora do Atlântico (Martinica)',
        'America/Matamoros' => 'Hora central norte-americana (Matamoros)',
        'America/Mazatlan' => 'Hora do Pacífico Mexicano (Mazatlan)',
        'America/Mendoza' => 'Hora da Argentina (Mendoza)',
        'America/Menominee' => 'Hora central norte-americana (Menominee)',
        'America/Merida' => 'Hora central norte-americana (Mérida)',
        'America/Metlakatla' => 'Hora do Alasca (Metlakatla)',
        'America/Mexico_City' => 'Hora central norte-americana (Cidade do México)',
        'America/Miquelon' => 'Hora de São Pedro e Miquelão (Miquelon)',
        'America/Moncton' => 'Hora do Atlântico (Moncton)',
        'America/Monterrey' => 'Hora central norte-americana (Monterrey)',
        'America/Montevideo' => 'Hora do Uruguai (Montevideu)',
        'America/Montserrat' => 'Hora do Atlântico (Monserrate)',
        'America/Nassau' => 'Hora oriental norte-americana (Nassau)',
        'America/New_York' => 'Hora oriental norte-americana (Nova Iorque)',
        'America/Nipigon' => 'Hora oriental norte-americana (Nipigon)',
        'America/Nome' => 'Hora do Alasca (Nome)',
        'America/Noronha' => 'Hora de Fernando de Noronha',
        'America/North_Dakota/Beulah' => 'Hora central norte-americana (Beulah, Dakota do Norte)',
        'America/North_Dakota/Center' => 'Hora central norte-americana (Center, Dakota do Norte)',
        'America/North_Dakota/New_Salem' => 'Hora central norte-americana (New Salen, Dakota do Norte)',
        'America/Ojinaga' => 'Hora central norte-americana (Ojinaga)',
        'America/Panama' => 'Hora oriental norte-americana (Panamá)',
        'America/Pangnirtung' => 'Hora oriental norte-americana (Pangnirtung)',
        'America/Paramaribo' => 'Hora do Suriname (Paramaribo)',
        'America/Phoenix' => 'Hora de montanha norte-americana (Phoenix)',
        'America/Port-au-Prince' => 'Hora oriental norte-americana (Port-au-Prince)',
        'America/Port_of_Spain' => 'Hora do Atlântico (Porto de Espanha)',
        'America/Porto_Velho' => 'Hora do Amazonas (Porto Velho)',
        'America/Puerto_Rico' => 'Hora do Atlântico (Porto Rico)',
        'America/Punta_Arenas' => 'Hora do Chile (Punta Arenas)',
        'America/Rainy_River' => 'Hora central norte-americana (Rainy River)',
        'America/Rankin_Inlet' => 'Hora central norte-americana (Rankin Inlet)',
        'America/Recife' => 'Hora de Brasília (Recife)',
        'America/Regina' => 'Hora central norte-americana (Regina)',
        'America/Resolute' => 'Hora central norte-americana (Resolute)',
        'America/Rio_Branco' => 'Hora do Acre (Rio Branco)',
        'America/Santa_Isabel' => 'Hora do Noroeste do México (Santa Isabel)',
        'America/Santarem' => 'Hora de Brasília (Santarém)',
        'America/Santiago' => 'Hora do Chile (Santiago)',
        'America/Santo_Domingo' => 'Hora do Atlântico (Santo Domingo)',
        'America/Sao_Paulo' => 'Hora de Brasília (São Paulo)',
        'America/Scoresbysund' => 'Hora da Gronelândia Oriental (Ittoqqortoormiit)',
        'America/Sitka' => 'Hora do Alasca (Sitka)',
        'America/St_Barthelemy' => 'Hora do Atlântico (São Bartolomeu)',
        'America/St_Johns' => 'Hora da Terra Nova (St. John’s)',
        'America/St_Kitts' => 'Hora do Atlântico (São Cristóvão)',
        'America/St_Lucia' => 'Hora do Atlântico (Santa Lúcia)',
        'America/St_Thomas' => 'Hora do Atlântico (St. Thomas)',
        'America/St_Vincent' => 'Hora do Atlântico (São Vicente)',
        'America/Swift_Current' => 'Hora central norte-americana (Swift Current)',
        'America/Tegucigalpa' => 'Hora central norte-americana (Tegucigalpa)',
        'America/Thule' => 'Hora do Atlântico (Thule)',
        'America/Thunder_Bay' => 'Hora oriental norte-americana (Thunder Bay)',
        'America/Tijuana' => 'Hora do Pacífico norte-americana (Tijuana)',
        'America/Toronto' => 'Hora oriental norte-americana (Toronto)',
        'America/Tortola' => 'Hora do Atlântico (Tortola)',
        'America/Vancouver' => 'Hora do Pacífico norte-americana (Vancouver)',
        'America/Whitehorse' => 'Hora do Yukon (Whitehorse)',
        'America/Winnipeg' => 'Hora central norte-americana (Winnipeg)',
        'America/Yakutat' => 'Hora do Alasca (Yakutat)',
        'America/Yellowknife' => 'Hora de montanha norte-americana (Yellowknife)',
        'Antarctica/Casey' => 'Hora de Antártida (Casey)',
        'Antarctica/Davis' => 'Hora de Davis',
        'Antarctica/DumontDUrville' => 'Hora de Dumont-d’Urville',
        'Antarctica/Macquarie' => 'Hora da Austrália Oriental (Macquarie)',
        'Antarctica/Mawson' => 'Hora de Mawson',
        'Antarctica/McMurdo' => 'Hora da Nova Zelândia (McMurdo)',
        'Antarctica/Palmer' => 'Hora do Chile (Palmer)',
        'Antarctica/Rothera' => 'Hora de Rothera',
        'Antarctica/Syowa' => 'Hora de Syowa',
        'Antarctica/Troll' => 'Hora de Greenwich (Troll)',
        'Antarctica/Vostok' => 'Hora de Vostok',
        'Arctic/Longyearbyen' => 'Hora da Europa Central (Longyearbyen)',
        'Asia/Aden' => 'Hora da Arábia (Adem)',
        'Asia/Almaty' => 'Hora do Cazaquistão Oriental (Almaty)',
        'Asia/Amman' => 'Hora da Europa Oriental (Amã)',
        'Asia/Anadyr' => 'Hora de Anadyr',
        'Asia/Aqtau' => 'Hora do Cazaquistão Ocidental (Aqtau)',
        'Asia/Aqtobe' => 'Hora do Cazaquistão Ocidental (Aqtobe)',
        'Asia/Ashgabat' => 'Hora do Turquemenistão (Asgabate)',
        'Asia/Atyrau' => 'Hora do Cazaquistão Ocidental (Atyrau)',
        'Asia/Baghdad' => 'Hora da Arábia (Bagdade)',
        'Asia/Bahrain' => 'Hora da Arábia (Barém)',
        'Asia/Baku' => 'Hora do Azerbaijão (Baku)',
        'Asia/Bangkok' => 'Hora da Indochina (Banguecoque)',
        'Asia/Barnaul' => 'Hora de Rússia (Barnaul)',
        'Asia/Beirut' => 'Hora da Europa Oriental (Beirute)',
        'Asia/Bishkek' => 'Hora do Quirguistão (Bishkek)',
        'Asia/Brunei' => 'Hora do Brunei Darussalam',
        'Asia/Calcutta' => 'Hora padrão da Índia (Calcutá)',
        'Asia/Chita' => 'Hora de Yakutsk (Chita)',
        'Asia/Choibalsan' => 'Hora de Ulan Bator (Choibalsan)',
        'Asia/Colombo' => 'Hora padrão da Índia (Colombo)',
        'Asia/Damascus' => 'Hora da Europa Oriental (Damasco)',
        'Asia/Dhaka' => 'Hora do Bangladeche (Daca)',
        'Asia/Dili' => 'Hora de Timor Leste (Dili)',
        'Asia/Dubai' => 'Hora padrão do Golfo (Dubai)',
        'Asia/Dushanbe' => 'Hora do Tajiquistão (Duchambe)',
        'Asia/Famagusta' => 'Hora da Europa Oriental (Famagusta)',
        'Asia/Gaza' => 'Hora da Europa Oriental (Gaza)',
        'Asia/Hebron' => 'Hora da Europa Oriental (Hebron)',
        'Asia/Hong_Kong' => 'Hora de Hong Kong',
        'Asia/Hovd' => 'Hora de Hovd',
        'Asia/Irkutsk' => 'Hora de Irkutsk',
        'Asia/Jakarta' => 'Hora da Indonésia Ocidental (Jacarta)',
        'Asia/Jayapura' => 'Hora da Indonésia Oriental (Jayapura)',
        'Asia/Jerusalem' => 'Hora de Israel (Jerusalém)',
        'Asia/Kabul' => 'Hora do Afeganistão (Cabul)',
        'Asia/Kamchatka' => 'Hora de Petropavlovsk-Kamchatski (Kamchatka)',
        'Asia/Karachi' => 'Hora do Paquistão (Carachi)',
        'Asia/Katmandu' => 'Hora do Nepal (Catmandu)',
        'Asia/Khandyga' => 'Hora de Yakutsk (Khandyga)',
        'Asia/Krasnoyarsk' => 'Hora de Krasnoyarsk',
        'Asia/Kuala_Lumpur' => 'Hora da Malásia (Kuala Lumpur)',
        'Asia/Kuching' => 'Hora da Malásia (Kuching)',
        'Asia/Kuwait' => 'Hora da Arábia (Koweit)',
        'Asia/Macau' => 'Hora da China (Macau)',
        'Asia/Magadan' => 'Hora de Magadan',
        'Asia/Makassar' => 'Hora da Indonésia Central (Macassar)',
        'Asia/Manila' => 'Hora das Filipinas (Manila)',
        'Asia/Muscat' => 'Hora padrão do Golfo (Mascate)',
        'Asia/Nicosia' => 'Hora da Europa Oriental (Nicósia)',
        'Asia/Novokuznetsk' => 'Hora de Krasnoyarsk (Novokuznetsk)',
        'Asia/Novosibirsk' => 'Hora de Novosibirsk',
        'Asia/Omsk' => 'Hora de Omsk',
        'Asia/Oral' => 'Hora do Cazaquistão Ocidental (Oral)',
        'Asia/Phnom_Penh' => 'Hora da Indochina (Phnom Penh)',
        'Asia/Pontianak' => 'Hora da Indonésia Ocidental (Pontianak)',
        'Asia/Pyongyang' => 'Hora da Coreia (Pyongyang)',
        'Asia/Qatar' => 'Hora da Arábia (Catar)',
        'Asia/Qostanay' => 'Hora do Cazaquistão Oriental (Kostanay)',
        'Asia/Qyzylorda' => 'Hora do Cazaquistão Ocidental (Qyzylorda)',
        'Asia/Rangoon' => 'Hora de Mianmar (Yangon)',
        'Asia/Riyadh' => 'Hora da Arábia (Riade)',
        'Asia/Saigon' => 'Hora da Indochina (Cidade de Ho Chi Minh)',
        'Asia/Sakhalin' => 'Hora de Sacalina',
        'Asia/Samarkand' => 'Hora do Uzbequistão (Samarcanda)',
        'Asia/Seoul' => 'Hora da Coreia (Seul)',
        'Asia/Shanghai' => 'Hora da China (Xangai)',
        'Asia/Singapore' => 'Hora padrão de Singapura',
        'Asia/Srednekolymsk' => 'Hora de Magadan (Srednekolymsk)',
        'Asia/Taipei' => 'Hora de Taipé',
        'Asia/Tashkent' => 'Hora do Uzbequistão (Tashkent)',
        'Asia/Tbilisi' => 'Hora da Geórgia (Tbilisi)',
        'Asia/Tehran' => 'Hora do Irão (Teerão)',
        'Asia/Thimphu' => 'Hora do Butão (Timphu)',
        'Asia/Tokyo' => 'Hora do Japão (Tóquio)',
        'Asia/Tomsk' => 'Hora de Rússia (Tomsk)',
        'Asia/Ulaanbaatar' => 'Hora de Ulan Bator',
        'Asia/Urumqi' => 'Hora de China (Urumqi)',
        'Asia/Ust-Nera' => 'Hora de Vladivostok (Ust-Nera)',
        'Asia/Vientiane' => 'Hora da Indochina (Vientiane)',
        'Asia/Vladivostok' => 'Hora de Vladivostok',
        'Asia/Yakutsk' => 'Hora de Yakutsk',
        'Asia/Yekaterinburg' => 'Hora de Ecaterimburgo',
        'Asia/Yerevan' => 'Hora da Arménia (Erevan)',
        'Atlantic/Azores' => 'Hora dos Açores',
        'Atlantic/Bermuda' => 'Hora do Atlântico (Bermudas)',
        'Atlantic/Canary' => 'Hora da Europa Ocidental (Canárias)',
        'Atlantic/Cape_Verde' => 'Hora de Cabo Verde',
        'Atlantic/Faeroe' => 'Hora da Europa Ocidental (Faroé)',
        'Atlantic/Madeira' => 'Hora da Europa Ocidental (Madeira)',
        'Atlantic/Reykjavik' => 'Hora de Greenwich (Reiquiavique)',
        'Atlantic/South_Georgia' => 'Hora da Geórgia do Sul',
        'Atlantic/St_Helena' => 'Hora de Greenwich (Santa Helena)',
        'Atlantic/Stanley' => 'Hora das Ilhas Falkland (Stanley)',
        'Australia/Adelaide' => 'Hora da Austrália Central (Adelaide)',
        'Australia/Brisbane' => 'Hora da Austrália Oriental (Brisbane)',
        'Australia/Broken_Hill' => 'Hora da Austrália Central (Broken Hill)',
        'Australia/Currie' => 'Hora da Austrália Oriental (Currie)',
        'Australia/Darwin' => 'Hora da Austrália Central (Darwin)',
        'Australia/Eucla' => 'Hora da Austrália Central Ocidental (Eucla)',
        'Australia/Hobart' => 'Hora da Austrália Oriental (Hobart)',
        'Australia/Lindeman' => 'Hora da Austrália Oriental (Lindeman)',
        'Australia/Lord_Howe' => 'Hora de Lord Howe (Ilha de Lord Howe)',
        'Australia/Melbourne' => 'Hora da Austrália Oriental (Melbourne)',
        'Australia/Perth' => 'Hora da Austrália Ocidental (Perth)',
        'Australia/Sydney' => 'Hora da Austrália Oriental (Sydney)',
        'CST6CDT' => 'Hora central norte-americana',
        'EST5EDT' => 'Hora oriental norte-americana',
        'Etc/GMT' => 'Hora de Greenwich',
        'Etc/UTC' => 'Hora Coordenada Universal',
        'Europe/Amsterdam' => 'Hora da Europa Central (Amesterdão)',
        'Europe/Andorra' => 'Hora da Europa Central (Andorra)',
        'Europe/Astrakhan' => 'Hora de Moscovo (Astracã)',
        'Europe/Athens' => 'Hora da Europa Oriental (Atenas)',
        'Europe/Belgrade' => 'Hora da Europa Central (Belgrado)',
        'Europe/Berlin' => 'Hora da Europa Central (Berlim)',
        'Europe/Bratislava' => 'Hora da Europa Central (Bratislava)',
        'Europe/Brussels' => 'Hora da Europa Central (Bruxelas)',
        'Europe/Bucharest' => 'Hora da Europa Oriental (Bucareste)',
        'Europe/Budapest' => 'Hora da Europa Central (Budapeste)',
        'Europe/Busingen' => 'Hora da Europa Central (Busingen)',
        'Europe/Chisinau' => 'Hora da Europa Oriental (Chisinau)',
        'Europe/Copenhagen' => 'Hora da Europa Central (Copenhaga)',
        'Europe/Dublin' => 'Hora de Greenwich (Dublin)',
        'Europe/Gibraltar' => 'Hora da Europa Central (Gibraltar)',
        'Europe/Guernsey' => 'Hora de Greenwich (Guernsey)',
        'Europe/Helsinki' => 'Hora da Europa Oriental (Helsínquia)',
        'Europe/Isle_of_Man' => 'Hora de Greenwich (Ilha de Man)',
        'Europe/Istanbul' => 'Hora de Turquia (Istambul)',
        'Europe/Jersey' => 'Hora de Greenwich (Jersey)',
        'Europe/Kaliningrad' => 'Hora da Europa Oriental (Caliningrado)',
        'Europe/Kiev' => 'Hora da Europa Oriental (Kiev)',
        'Europe/Kirov' => 'Hora de Rússia (Kirov)',
        'Europe/Lisbon' => 'Hora da Europa Ocidental (Lisboa)',
        'Europe/Ljubljana' => 'Hora da Europa Central (Liubliana)',
        'Europe/London' => 'Hora de Greenwich (Londres)',
        'Europe/Luxembourg' => 'Hora da Europa Central (Luxemburgo)',
        'Europe/Madrid' => 'Hora da Europa Central (Madrid)',
        'Europe/Malta' => 'Hora da Europa Central (Malta)',
        'Europe/Mariehamn' => 'Hora da Europa Oriental (Mariehamn)',
        'Europe/Minsk' => 'Hora de Moscovo (Minsk)',
        'Europe/Monaco' => 'Hora da Europa Central (Mónaco)',
        'Europe/Moscow' => 'Hora de Moscovo',
        'Europe/Oslo' => 'Hora da Europa Central (Oslo)',
        'Europe/Paris' => 'Hora da Europa Central (Paris)',
        'Europe/Podgorica' => 'Hora da Europa Central (Podgorica)',
        'Europe/Prague' => 'Hora da Europa Central (Praga)',
        'Europe/Riga' => 'Hora da Europa Oriental (Riga)',
        'Europe/Rome' => 'Hora da Europa Central (Roma)',
        'Europe/Samara' => 'Hora de Samara',
        'Europe/San_Marino' => 'Hora da Europa Central (São Marinho)',
        'Europe/Sarajevo' => 'Hora da Europa Central (Sarajevo)',
        'Europe/Saratov' => 'Hora de Moscovo (Saratov)',
        'Europe/Simferopol' => 'Hora de Moscovo (Simferopol)',
        'Europe/Skopje' => 'Hora da Europa Central (Skopje)',
        'Europe/Sofia' => 'Hora da Europa Oriental (Sófia)',
        'Europe/Stockholm' => 'Hora da Europa Central (Estocolmo)',
        'Europe/Tallinn' => 'Hora da Europa Oriental (Talim)',
        'Europe/Tirane' => 'Hora da Europa Central (Tirana)',
        'Europe/Ulyanovsk' => 'Hora de Moscovo (Ulianovsk)',
        'Europe/Uzhgorod' => 'Hora da Europa Oriental (Uzhgorod)',
        'Europe/Vaduz' => 'Hora da Europa Central (Vaduz)',
        'Europe/Vatican' => 'Hora da Europa Central (Vaticano)',
        'Europe/Vienna' => 'Hora da Europa Central (Viena)',
        'Europe/Vilnius' => 'Hora da Europa Oriental (Vilnius)',
        'Europe/Volgograd' => 'Hora de Volgogrado',
        'Europe/Warsaw' => 'Hora da Europa Central (Varsóvia)',
        'Europe/Zagreb' => 'Hora da Europa Central (Zagreb)',
        'Europe/Zaporozhye' => 'Hora da Europa Oriental (Zaporizhia)',
        'Europe/Zurich' => 'Hora da Europa Central (Zurique)',
        'Indian/Antananarivo' => 'Hora da África Oriental (Antananarivo)',
        'Indian/Chagos' => 'Hora do Oceano Índico (Chagos)',
        'Indian/Christmas' => 'Hora da Ilha do Natal',
        'Indian/Cocos' => 'Hora das Ilhas Cocos',
        'Indian/Comoro' => 'Hora da África Oriental (Comores)',
        'Indian/Kerguelen' => 'Hora das Terras Austrais e Antárcticas Francesas (Kerguelen)',
        'Indian/Mahe' => 'Hora das Seicheles (Mahe)',
        'Indian/Maldives' => 'Hora das Maldivas',
        'Indian/Mauritius' => 'Hora da Maurícia',
        'Indian/Mayotte' => 'Hora da África Oriental (Mayotte)',
        'Indian/Reunion' => 'Hora de Reunião',
        'MST7MDT' => 'Hora de montanha norte-americana',
        'PST8PDT' => 'Hora do Pacífico norte-americana',
        'Pacific/Apia' => 'Hora de Apia',
        'Pacific/Auckland' => 'Hora da Nova Zelândia (Auckland)',
        'Pacific/Bougainville' => 'Hora de Papua Nova Guiné (Bougainville)',
        'Pacific/Chatham' => 'Hora de Chatham',
        'Pacific/Easter' => 'Hora da Ilha da Páscoa',
        'Pacific/Efate' => 'Hora do Vanuatu (Efate)',
        'Pacific/Enderbury' => 'Hora das Ilhas Fénix (Enderbury)',
        'Pacific/Fakaofo' => 'Hora de Tokelau (Fakaofo)',
        'Pacific/Fiji' => 'Hora de Fiji',
        'Pacific/Funafuti' => 'Hora de Tuvalu (Funafuti)',
        'Pacific/Galapagos' => 'Hora das Galápagos',
        'Pacific/Gambier' => 'Hora de Gambier',
        'Pacific/Guadalcanal' => 'Hora das Ilhas Salomão (Guadalcanal)',
        'Pacific/Guam' => 'Hora padrão de Chamorro (Guam)',
        'Pacific/Honolulu' => 'Hora do Havai e Aleutas (Honolulu)',
        'Pacific/Johnston' => 'Hora do Havai e Aleutas (Johnston)',
        'Pacific/Kiritimati' => 'Hora das Ilhas Line (Kiritimati)',
        'Pacific/Kosrae' => 'Hora de Kosrae',
        'Pacific/Kwajalein' => 'Hora das Ilhas Marshall (Kwajalein)',
        'Pacific/Majuro' => 'Hora das Ilhas Marshall (Majuro)',
        'Pacific/Marquesas' => 'Hora das Ilhas Marquesas',
        'Pacific/Midway' => 'Hora de Samoa (Midway)',
        'Pacific/Nauru' => 'Hora de Nauru',
        'Pacific/Niue' => 'Hora de Niuê (Niue)',
        'Pacific/Norfolk' => 'Hora da Ilha Norfolk',
        'Pacific/Noumea' => 'Hora da Nova Caledónia (Nouméa)',
        'Pacific/Pago_Pago' => 'Hora de Samoa (Pago Pago)',
        'Pacific/Palau' => 'Hora de Palau',
        'Pacific/Pitcairn' => 'Hora de Pitcairn (Ilhas Pitcairn)',
        'Pacific/Ponape' => 'Hora de Ponape (Pohnpei)',
        'Pacific/Port_Moresby' => 'Hora de Papua Nova Guiné (Port Moresby)',
        'Pacific/Rarotonga' => 'Hora das Ilhas Cook (Rarotonga)',
        'Pacific/Saipan' => 'Hora padrão de Chamorro (Saipan)',
        'Pacific/Tahiti' => 'Hora do Taiti',
        'Pacific/Tarawa' => 'Hora das Ilhas Gilbert (Tarawa)',
        'Pacific/Tongatapu' => 'Hora de Tonga (Tongatapu)',
        'Pacific/Truk' => 'Hora de Chuuk',
        'Pacific/Wake' => 'Hora da Ilha Wake',
        'Pacific/Wallis' => 'Hora de Wallis e Futuna',
    ],
    'Meta' => [
    ],
];
